@@ -98,7 +98,7 @@ void Permedia3InitVideo(ScreenPtr pScreen)
 	    adaptors = &newAdaptor;
 	} else {
 	    newAdaptors =  /* need to free this someplace */
-		xalloc((num_adaptors + 1) * sizeof(XF86VideoAdaptorPtr*));
+		malloc((num_adaptors + 1) * sizeof(XF86VideoAdaptorPtr *));
 	    if(newAdaptors) {
 		memcpy(newAdaptors, adaptors, num_adaptors * 
 					sizeof(XF86VideoAdaptorPtr));
@@ -112,8 +112,7 @@ void Permedia3InitVideo(ScreenPtr pScreen)
     if(num_adaptors)
         xf86XVScreenInit(pScreen, adaptors, num_adaptors);
 
-    if(newAdaptors)
-	xfree(newAdaptors);
+    free(newAdaptors);
 }
 
 /* client libraries expect an encoding */
@@ -288,7 +287,7 @@ Permedia3SetupImageVideo(ScreenPtr pScreen)
     XF86VideoAdaptorPtr adapt;
     GLINTPortPrivPtr pPriv;
 
-    if(!(adapt = xcalloc(1, sizeof(XF86VideoAdaptorRec) +
+    if(!(adapt = calloc(1, sizeof(XF86VideoAdaptorRec) +
 			    sizeof(GLINTPortPrivRec) +
 			    sizeof(DevUnion))))
 	return NULL;
@@ -1030,12 +1029,12 @@ Permedia3AllocateSurface(
     surface->width = w;
     surface->height = h;
 
-    if(!(surface->offsets = xalloc(sizeof(int)))) {
+    if(!(surface->offsets = malloc(sizeof(int)))) {
 	xf86FreeOffscreenArea(area);
 	return BadAlloc;
     }
-    if(!(pPriv = xalloc(sizeof(OffscreenPrivRec)))) {
-	xfree(surface->offsets);
+    if(!(pPriv = malloc(sizeof(OffscreenPrivRec)))) {
+	free(surface->offsets);
 	xf86FreeOffscreenArea(area);
 	return BadAlloc;
     }
@@ -1080,9 +1079,9 @@ Permedia3FreeSurface(
     if(pPriv->isOn)
 	Permedia3StopSurface(surface);
     xf86FreeOffscreenArea(pPriv->area);
-    xfree(surface->pitches);
-    xfree(surface->offsets);
-    xfree(surface->devPrivate.ptr);
+    free(surface->pitches);
+    free(surface->offsets);
+    free(surface->devPrivate.ptr);
 
     return Success;
 }
@@ -1235,7 +1234,7 @@ Permedia3InitOffscreenImages(ScreenPtr pScreen)
     XF86OffscreenImagePtr offscreenImages;
 
     /* need to free this someplace */
-    if(!(offscreenImages = xalloc(sizeof(XF86OffscreenImageRec))))
+    if(!(offscreenImages = malloc(sizeof(XF86OffscreenImageRec))))
 	return;
 
     offscreenImages[0].image = &Images[0];
